@@ -48,12 +48,24 @@ class Node:
         :return: null
         :rtype: null
         """
-        command = "geth --identity {0} --http --http.port {1} --http.corsdomain \"*\" --datadir \"{2}\" --port " \
-                  "{3} --nodiscover --http.api  \"eth,net,web3,personal,miner,admin\" --networkid {4} --nat " \
-                  "\"any\" --ipcdisable --allow-insecure-unlock ".format(str(self.name), str(self.rpcport),
-                                                                         str(self.datadir),
-                                                                         str(self.port), str(self.network_id))
-        self.process = Popen(command, stdout=subprocess.PIPE, shell=True)
+        if os.name == 'nt':
+            command = "geth --identity {0} --http --http.port {1} --http.corsdomain \"*\" --datadir \"{2}\" --port " \
+                      "{3} --nodiscover --http.api  \"eth,net,web3,personal,miner,admin\" --networkid {4} --nat " \
+                      "\"any\" --ipcdisable --allow-insecure-unlock ".format(str(self.name), str(self.rpcport),
+                                                                             str(self.datadir),
+                                                                             str(self.port), str(self.network_id))
+
+            self.process = Popen(command)
+
+        else:
+            command = "exec geth --identity {0} --http --http.port {1} --http.corsdomain \"*\" --datadir \"{2}\" " \
+                      "--port " \
+                      "{3} --nodiscover --http.api  \"eth,net,web3,personal,miner,admin\" --networkid {4} --nat " \
+                      "\"any\" --ipcdisable --allow-insecure-unlock ".format(str(self.name), str(self.rpcport),
+                                                                             str(self.datadir),
+                                                                             str(self.port), str(self.network_id))
+
+            self.process = Popen(command, stdout=subprocess.PIPE, shell=True)
 
         self.w3 = Web3(HTTPProvider('http://127.0.0.1:{}'.format(self.rpcport)))
         counter = 0
